# -*- coding: utf-8 -*-

"""
Load one particular book and import into database...
"""


from nashi import app
from models import Book, Page
from database import db_session
from glob import glob
from os import path
from lxml import etree

TEXTDIRECTION = 'horizontal-lr'

bookpath = app.config["LAREX_DIR"]+"/Ptolemy_Syntaxis-mathematica-2_gr"

bookname = path.split(bookpath)[1]
no_pages_total = len(glob(bookpath+"/*.png"))

book = Book.query.filter_by(name=bookname).first()
if not book:
    book = Book(name=bookname, no_pages_total=no_pages_total)
else:
    book.no_pages_total = no_pages_total

print(bookname)

for xmlfile in sorted(glob(bookpath+"/*.xml")):
    pagename = path.splitext(path.split(xmlfile)[1])[0]
    print(pagename)

    page = Page.query.filter_by(book_id=book.id, name=pagename).first()
    if not page:
        page = Page(book=book, name=pagename)

    root = etree.parse(xmlfile).getroot()
    ns = {"ns": root.nsmap[None]}

    textregions = root.xpath('//ns:TextRegion', namespaces=ns)

    page.no_lines_segm = int(root.xpath("count(//ns:TextLine)", namespaces=ns))
    page.no_lines_gt = int(root.xpath(
        'count(//ns:TextLine/ns:TextEquiv[@index="0"])', namespaces=ns))
    page.no_lines_ocr = int(root.xpath("count(//ns:TextLine)", namespaces=ns))
    page.data = etree.tounicode(root.getroottree()).replace(
             "http://schema.primaresearch.org/PAGE/gts/pagecontent/2010-03-19",
             "http://schema.primaresearch.org/PAGE/gts/pagecontent/2017-07-15"
            )


db_session.add(book)

db_session.commit()



# -*- coding: utf-8 -*-

from nashi.models import Book
from nashi.database import db_session

from glob import glob
from os import path, mkdir, symlink, chmod
from shutil import chown, copy


def scan_bookfolder(bookfolder):
    """ Scan bookfolder and write book info to database. """
    books = glob(bookfolder + "//*/")
    for bookpath in books:
        bookname = path.split(bookpath[:-1])[1]
        files = set([f.split(sep=".")[0] for f in glob(bookpath+"*.png")])
        no_pages_total = len(files)
        book = Book.query.filter_by(name=bookname).first()
        if not book:
            book = Book(name=bookname, no_pages_total=no_pages_total)
            db_session.add(book)
        else:
            book.no_pages_total = no_pages_total
    db_session.commit()


def copy_to_larex(bookname, booksdir, larexdir, larexgrp):
    pngfiles = glob("{}/{}/*.png".format(booksdir, bookname))
    pages = set([path.split(f)[1].split(".")[0] for f in pngfiles])
    cpimgs = []
    for p in sorted(pages):
        fullbinp = "{}/{}/{}.bin.png".format(booksdir, bookname, p)
        fullnrmp = "{}/{}/{}.nrm.png".format(booksdir, bookname, p)
        if fullbinp in pngfiles:
            cpimgs.append(fullbinp)
        elif fullnrmp in pngfiles:
            cpimgs.append(fullnrmp)
        else:
            cpimgs.append([x for x in pngfiles if path.split(x)[1].startswith(
                p+".")][0])
    if cpimgs:
        if not path.isdir(larexdir + "/" + bookname):
            mkdir(larexdir + "/" + bookname)
            chmod(larexdir + "/" + bookname, 0o770)
            try:
                chown(larexdir + "/" + bookname, group=larexgrp)
            except PermissionError:
                pass  # Needs error handling, maybe flash?
        for f in cpimgs:
            fname = path.split(f)[1]
            if not path.isfile("{}/{}/{}".format(larexdir, bookname, fname)):
                symlink(f, "{}/{}/{}".format(larexdir, bookname, fname))
            # copy(f, "{}/{}/{}".format(larexdir, bookname, fname))
    return len(cpimgs)
